@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -130,7 +130,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.001001
+version 1.001002
 
 =head1 SYNOPSIS
 
@@ -181,8 +181,8 @@ the following list:>
 	v1.234.5
 	2.3456
 
-you can cause your tests to fail if not strict by setting L<is_strict> to
-C<2>
+you can cause your tests to fail if not strict by setting L<is_strict|/is_strict> to
+C<1>
 
 =back
 
@@ -211,7 +211,7 @@ C<blib> or C<lib> if you haven't passed it a directory.
 Allows disabling whether a module has to have a version. If set to 0
 version tests will be skipped in any module where no version is found.
 
-really doesn't make sense to use with just L<version_ok>
+really doesn't make sense to use with just L<version_ok|/version_ok>
 
 =head2 is_strict
 
